@@ -27,7 +27,7 @@ echo "Making start scripts"
 echo "GST_PLUGIN_PATH=../lib/jammo/ ./jammo \$@" > $PREFIX/bin/jammo.sh
 chmod a+x $PREFIX/bin/jammo.sh
 
-echo "GST_PLUGIN_PATH=../lib/jammo/ ./jammoterminal \$@" > $PREFIX/bin/jammoterminal.sh
+echo "GST_PLUGIN_PATH=../lib/jammo/ ./jammoterminal \$@ reset" > $PREFIX/bin/jammoterminal.sh
 chmod a+x $PREFIX/bin/jammoterminal.sh
 
 echo "cd usr/bin/ && ./jammo.sh \$@" > jammo.sh
