@@ -11,13 +11,18 @@ all the user actions to CEM fo logging/mentor input/game input."
 #include <fcntl.h> //we check some files
 #include <string.h> //we use strcmp
 #include <pthread.h> // we use threads when debugging
+#include <unistd.h>
 
 #include "gui.h"
 #include "chum.h"
 #include "file_helper.h"
 
 #include "../cem/cem.h"
-#include "../meam/meam.h"
+#include "../meam/jammo-meam.h"
+#include "../meam/jammo-sample.h"
+#include "../meam/jammo-editing-track.h"
+#include "../meam/jammo-recording-track.h"
+#include "../meam/jammo-instrument-track.h"
 
 #include "../gems/gems.h"
 
@@ -29,6 +34,29 @@ int state_of_chum=SCREEN_WELCOME;
 int current_theme; /*for composing game*/
 int current_song;  /*for karaoke game*/
 
+//This is not same than language from profile (which affects speech of mentor)
+//This is only when user wants sing a song in different language.
+char* selected_language="";
+
+//This helps logging/debugging state switching
+char *name_of_states[] ={ "SCREEN_WELCOME",
+                          "SCREEN_PASSWORD_TYPING",
+                          "SCREEN_GAME_SELECTION",
+                          "SCREEN_THEME_SELECTION",
+                          "SCREEN_COMPOSING",
+                          "SCREEN_SONG_SELECTION",
+                          "SCREEN_SONG_RECORDING",
+                          "SCREEN_PLAY_RECORDED",
+                          "SCREEN_PLAY_RECORDED",
+                          "SCREEN_MIDI_EDITOR" };
+
+static JammoSequencer* sequencer = NULL;
+JammoEditingTrack* editing_track;
+JammoEditingTrack* backing_track;
+
+JammoInstrumentTrack* instrument_track;
+JammoRecordingTrack* recording_track;
+
 gint number_of_themes = 0;
 gint chum_get_number_of_themes(){
 return number_of_themes;
@@ -41,24 +69,24 @@ return state_of_chum;
 //THIS IS THE MAIN LOOP OF JAMMO!!!
 void chum_start_jammo_main_loop() {
     cem_add_to_log("starting main loop",LOG_DEBUG);
-    //meam_start_gstreamer_loop();
-
-    //This is not good for jammoterminal but it works.
-    //gtk_main();
     gui_start_main_loop();
-    //clutter_init();
-    //clutter_main();
     cem_add_to_log("main loop is over",LOG_DEBUG);
 }
 
 
 void *debug_test_wait_and_start_seq(){
-  printf("wait_and_start_seq\n");
+  printf("wait_and_start_seq...1second\n");
   g_usleep( 1 * G_USEC_PER_SEC );
   chum_play_sequencer();
+  
+  /* if making profiling
+  printf("wait_and_start_seq...100 second\n");
+  g_usleep( 100 * G_USEC_PER_SEC );
+  exit(0);*/
   pthread_exit(NULL);
 }
 
+#if 0
 void debug_test_minimal_recording(int different_way) {
     int song_number=4;
     cem_add_to_log(g_strdup_printf("debug_test_minimal_recording(%d)",different_way),LOG_DEBUG);
@@ -71,7 +99,7 @@ void debug_test_minimal_recording(int different_way) {
       {
       cem_add_to_log(g_strdup_printf("making new_empty_track and put sample to it"),LOG_DEBUG);
       chum_create_new_empty_track(); //for comping track
-      chum_add_new_sample_to_track_nth_slot(0,filename,0);
+      chum_add_new_sample_to_track_nth_slot(backing_track,filename,0);
       }
     else
       {
@@ -85,13 +113,9 @@ void debug_test_minimal_recording(int different_way) {
     pthread_t loop_thread;
     pthread_create(&loop_thread, NULL, debug_test_wait_and_start_seq, NULL);
 
-    GMainLoop *loop;
-    loop = g_main_loop_new (NULL, FALSE);
-    g_main_loop_run (loop);
-    //This is useless:
-    pthread_exit(NULL);
+    chum_start_jammo_main_loop();
 }
-
+#endif
 
 void chum_start_chum(int argc, char** argv){
     int i;
@@ -101,33 +125,37 @@ void chum_start_chum(int argc, char** argv){
     if (error_code)
         printf("Error, can't call '%s'\n",cmd);
     #endif
-    
+
     cem_add_to_log("chum_start_chum()",LOG_DEBUG);
     for (i=1;i<argc;i++) 
       {
       cem_add_to_log(g_strdup_printf("chum_start_chum(%s)",argv[i]),LOG_DEBUG);
       }
     //init for sequencer
-    meam_init();
+    jammo_meam_init(&argc, &argv);
     number_of_themes=chum_count_themes();
 
     if (argc==2 && strcmp(argv[1],"--help")==0) {
         printf("\nJamMo help:\n\n");
         printf("flags:\n");
         printf("editor  \t- start midi-editor\n");
-        printf("theme n \t- start composing game in theme n\n\n");
+        printf("theme n \t- start composing game in theme n\n");
+        printf("password \t- test password typing\n\n");
         exit(0);
         }
 
     else if (argc==2 && strcmp(argv[1],"debug0")==0) { 
-        debug_test_minimal_recording(0);
+//        debug_test_minimal_recording(0);
         exit(0);
         }
     else if (argc==2 && strcmp(argv[1],"debug1")==0) { 
-        debug_test_minimal_recording(1);
+//        debug_test_minimal_recording(1);
         exit(0);
         }
 
+    else if (argc==2 && strcmp(argv[1],"password")==0) { 
+        state_of_chum=SCREEN_PASSWORD_TYPING;
+        }
 
 
     gui_init();
@@ -143,6 +171,9 @@ void chum_start_chum(int argc, char** argv){
         state_of_chum=SCREEN_THEME_SELECTION;
         }
 
+    else if (argc==2 && strcmp(argv[1],"sequencer")==0) {
+        state_of_chum=SCREEN_SEQUENCER;
+        }
 
     else if (argc==3 && strcmp(argv[1],"theme")==0) { 
         chum_change_theme(atoi(argv[2]));
@@ -154,8 +185,22 @@ void chum_start_chum(int argc, char** argv){
 
     chum_start_jammo_main_loop();
 }
-char *name_of_states[] = {"SCREEN_WELCOME","SCREEN_GAME_SELECTION","SCREEN_THEME_SELECTION","SCREEN_COMPOSING","SCREEN_SONG_SELECTION","SCREEN_SONG_RECORDING","SCREEN_PLAY_RECORDED","SCREEN_PLAY_RECORDED","SCREEN_MIDI_EDITOR"};
 
+void chum_test_instrument(int type) {
+	cem_add_to_log(g_strdup_printf("chum_test_instrument(%d)",type),LOG_DEBUG);
+	sequencer = jammo_sequencer_new();
+	instrument_track = jammo_instrument_track_new(type);
+	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(instrument_track));
+	
+  //Instrument track doesn't work if there aren't another track with one sample.
+	editing_track = jammo_editing_track_new();
+	JammoSample* sample;
+	gchar* filepath1 = g_strdup_printf("%s/themes/forest/loop1.wav",DATA_DIR);
+	sample = jammo_sample_new_from_file(filepath1);
+	jammo_editing_track_add_sample(editing_track, sample, 0);
+	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(editing_track));
+
+}
 void chum_go_back() {
     cem_add_to_log(g_strdup_printf("chum_go_back(). state_of_chum was %s...",name_of_states[state_of_chum]),LOG_DEBUG);
 
@@ -168,9 +213,7 @@ void chum_go_back() {
 	  state_of_chum=SCREEN_SONG_SELECTION;
 	  break;
       case SCREEN_PLAY_RECORDED:
-	  //state_of_chum=SCREEN_SONG_RECORDING;
-          chum_stop_sequencer();
-          chum_change_to_song(chum_get_current_song());
+	  state_of_chum=SCREEN_SONG_RECORDING;
 	  break;
 
       //composing
@@ -202,6 +245,13 @@ void chum_go_next() {
       case SCREEN_PLAY_RECORDED:
 	  state_of_chum=SCREEN_SONG_SELECTION;
 	  break;
+		case SCREEN_WELCOME:
+	  state_of_chum=SCREEN_GAME_SELECTION;
+	  break;
+		case SCREEN_PASSWORD_TYPING:
+	  state_of_chum=SCREEN_WELCOME;
+	  break;
+
       default:
 	state_of_chum++;
 	break;
@@ -229,24 +279,37 @@ int chum_get_current_theme(){
     return current_theme;
 }
 
-void chum_create_new_empty_track() {
-  cem_add_to_log(g_strdup_printf("chum_create_new_empty_track()"),LOG_DEBUG);
-  meam_create_new_empty_track();
+JammoEditingTrack* chum_create_new_empty_track() {
+	JammoEditingTrack* track;
+
+	cem_add_to_log(g_strdup_printf("chum_create_new_empty_track()"),LOG_DEBUG);
+	track = jammo_editing_track_new();
+	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(track));
+
+	return track;
 }
 void chum_change_theme(int theme_number){
+	JammoSample* sample;
+	
     cem_add_to_log(g_strdup_printf("chum_change_theme(%d)",theme_number),LOG_DEBUG);
     current_theme=theme_number;
 
-    g_list_foreach(get_mainPipeline()->tracks, (GFunc)remove_track, NULL);
-    chum_create_new_empty_track(); //for samples
-    chum_create_new_empty_track(); //for backing track
+	if (sequencer) {
+		g_object_unref(sequencer);
+	}
+	sequencer = jammo_sequencer_new();
+	editing_track = chum_create_new_empty_track(); //for samples
+	backing_track = chum_create_new_empty_track(); //for backing track
 
 
     //Add backing track if there are.
     gchar* filepath1 = g_strdup_printf("%s/%s/backing_track.wav", THEMES_DIR, chum_get_theme_folder(chum_get_current_theme()));
     int fd = open(filepath1,O_RDONLY);
-    if (fd != -1)
-	meam_seq_add_new_sample_to_track(1,filepath1,0); //trac-number,file,starting position
+    if (fd != -1) {
+	sample = jammo_sample_new_from_file(filepath1);
+	jammo_editing_track_add_sample(backing_track, sample, 0);
+	close(fd);
+    }
 
     state_of_chum=SCREEN_COMPOSING;
     //gui_go_screen(state_of_chum);
@@ -258,15 +321,6 @@ chum_change_theme(theme_number);
     gui_go_screen(state_of_chum);
 }
 
-/* If this is needed, it should be moved to track.c or pipeline.c
-It doesn't call free_track, so it can waste memory */
-void remove_track (Track *trc){
-printf("chum: remove_track begin\n");
-get_mainPipeline()->tracks =  g_list_remove(get_mainPipeline()->tracks, trc);
-	gst_bin_remove(GST_BIN(get_mainPipeline()->pipeline), trc->trackbin);
-free_track(trc);
-}
-
 int chum_get_current_song(){
 cem_add_to_log(g_strdup_printf("get_current_song(). will return %d",current_song),LOG_DEBUG);
     return current_song;
@@ -281,19 +335,30 @@ return name;
 /*STATIC
 Always call this before gui_go_screen(SCREEN_PLAY_RECORDED);
 */
+#ifdef N900
+#define RECORDING_FILENAME "/home/user/.jammo/recording.wav"
+#else
+#define RECORDING_FILENAME "/tmp/recording.wav"
+#endif
 static void chum_play_recorded_and_backing_track(){
     chum_stop_sequencer();
-    g_list_foreach(get_mainPipeline()->tracks, (GFunc)remove_track, NULL);
+    /*
+	if (sequencer) {
+		g_object_unref(sequencer);
+	}
+    */
+	sequencer = jammo_sequencer_new();
 
-
-    chum_create_new_empty_track(); //for comping track
+	backing_track = chum_create_new_empty_track(); //for comping track
     const gchar *song_folder=chum_get_song_folder(chum_get_current_song());
-    gchar *filename = g_strdup_printf("%s/comping.ogg", song_folder);
-    chum_add_new_sample_to_track_nth_slot(0,filename,0);
+    //gchar *filename = g_strdup_printf("%s/comping.ogg", song_folder);
+    //printf("language is '%s'\n",selected_language);
+    gchar *filename = g_strdup_printf("%s/comping%s.ogg", song_folder,selected_language);
+    chum_add_new_sample_to_track_nth_slot(backing_track,filename,0);
 
+    editing_track = chum_create_new_empty_track(); //for recorded singing
+    chum_add_new_sample_to_track_nth_slot(editing_track,RECORDING_FILENAME,0);
 
-    chum_create_new_empty_track(); //for recorded singing
-    chum_add_new_sample_to_track_nth_slot(1,REC_TARGET,0);
 }
 
 
@@ -301,40 +366,39 @@ void chum_change_to_song(int song_number){
     cem_add_to_log(g_strdup_printf("chum_change_to_song(%d)",song_number),LOG_DEBUG);
     current_song=song_number;
 
-    meam_seq_remove_samples_from_track(0);
-    meam_seq_remove_samples_from_track(1);
+	if (sequencer) {
+		g_object_unref(sequencer);
+	}
+	sequencer = jammo_sequencer_new();
 
     const gchar *song_folder=chum_get_song_folder(song_number);
 
-    g_list_foreach(get_mainPipeline()->tracks, (GFunc)remove_track, NULL);
-    chum_create_new_empty_track(); //for comping track
-    gchar *filename = g_strdup_printf("%s/comping.ogg", song_folder);
-    chum_add_new_sample_to_track_nth_slot(0,filename,0);
+    backing_track = chum_create_new_empty_track(); //for comping track
+    //gchar *filename = g_strdup_printf("%s/comping.ogg", song_folder);
+    gchar *filename = g_strdup_printf("%s/comping%s.ogg", song_folder,selected_language);
+    chum_add_new_sample_to_track_nth_slot(backing_track,filename,0);
+
+    chum_add_new_sample_to_track_nth_slot(backing_track,filename,0);
+
+    
+    recording_track = jammo_recording_track_new_with_pitch_detect(RECORDING_FILENAME);
+    jammo_sequencer_add_track(sequencer, JAMMO_TRACK(recording_track));
 
-    create_new_singing_track();
     state_of_chum=SCREEN_SONG_RECORDING;
-}
-
-void chum_play_one_sample(char* filename){
-    cem_add_to_log(g_strdup_printf("chum_play_one_sample(%s)",filename),LOG_DEBUG);
-    meam_play_one_sample(filename);
-}
-
-void chum_stop_one_sample(){
-    cem_add_to_log("chum_stop_one_sample()",LOG_DEBUG);
-    meam_stop_one_sample();
+    gui_go_screen(state_of_chum);
 }
 
 void chum_stop_sequencer(){
     cem_add_to_log("chum_stop_sequencer()",LOG_DEBUG);
-    meam_seq_stop();
+    jammo_sequencer_stop(sequencer);
 }
 
 void chum_play_sequencer(){
-    chum_stop_sequencer();
+	
+  //  chum_stop_sequencer();
     cem_add_to_log("chum_play_sequencer()",LOG_DEBUG);
     gui_visualize_playing(state_of_chum);
-    meam_seq_play();
+	jammo_sequencer_play(sequencer);
 }
 
 void chum_report_melodic_contour(float freq){
@@ -343,27 +407,41 @@ gui_visualize_contour(freq);
 
 
 void chum_get_duration_of_song(guint64 *value) {
-    meam_get_duration_of_song(value);
+	*value = jammo_sequencer_get_duration(sequencer);
 }
 
 //FIX: implement this.
 //void chum_pause_sequencer();
 
-Sample *chum_add_new_sample_to_track(int track_number, const gchar srcLocation[], guint64 startTime){
-    cem_add_to_log(g_strdup_printf("chum_add_new_sample_to_track(%d,%s,%" GST_TIME_FORMAT ")",track_number, srcLocation, GST_TIME_ARGS (startTime)),LOG_DEBUG);
-    return meam_seq_add_new_sample_to_track(track_number, srcLocation, startTime);
+JammoSample* chum_add_new_sample_to_track(JammoEditingTrack* track, const gchar* srcLocation, guint64 startTime){
+	JammoSample* sample;
+
+    cem_add_to_log(g_strdup_printf("chum_add_new_sample_to_track(%p,%s,%" GST_TIME_FORMAT ")",track, srcLocation, GST_TIME_ARGS (startTime)),LOG_DEBUG);
+
+	sample = jammo_sample_new_from_file(srcLocation);
+	jammo_editing_track_add_sample(track, sample, startTime);
+	return sample;
 }
 
 
-Sample *chum_add_new_sample_to_track_nth_slot(int track_number, const gchar srcLocation[], guint slot){
-    cem_add_to_log(g_strdup_printf("chum_add_new_sample_to_track_nth_slot(%d,%s,%d)",track_number, srcLocation, slot),LOG_DEBUG);
-    return meam_seq_add_new_sample_to_track_nth_slot(track_number, srcLocation, slot);
+JammoSample* chum_add_new_sample_to_track_nth_slot(JammoEditingTrack* track, const gchar* srcLocation, guint slot){
+	JammoSample* sample;
+	
+    cem_add_to_log(g_strdup_printf("chum_add_new_sample_to_track_nth_slot(%p,%s,%d)",track, srcLocation, slot),LOG_DEBUG);
+
+	sample = jammo_sample_new_from_file(srcLocation);
+	jammo_editing_track_add_sample(track, sample, slot * GST_SECOND); /* TODO: Slot is one second now. */
+	return sample;
 }
 
+void chum_remove_sample_from_slot(JammoEditingTrack* track, int slot){
+	JammoSample* sample;
 
-void chum_remove_sample_from_slot(guint track_number,int slot){
-cem_add_to_log(g_strdup_printf("chum_remove_sample_from_slot(track=%d,slot=%d)",track_number,slot),LOG_DEBUG);
-meam_remove_sample_from_slot(track_number,slot);
+cem_add_to_log(g_strdup_printf("chum_remove_sample_from_slot(track=%p,slot=%d)",track,slot),LOG_DEBUG);
+
+	if ((sample = jammo_editing_track_get_sample(track, slot * GST_SECOND))) { /* TODO: Slot is one second now. */
+		jammo_editing_track_remove_sample(track, sample);
+	}
 }
 
 //FIX: we should not use fixed value
@@ -400,43 +478,54 @@ return number_of_themes;
 
 void chum_get_all_slot_info(int track_number){
 cem_add_to_log(g_strdup_printf("chum_get_all_slot_info(%d)",track_number),LOG_DEBUG);
-meam_get_all_slot_info(track_number);
+//meam_get_all_slot_info(track_number);
 }
 
 void chum_add_instrument_track(int type) {
 cem_add_to_log(g_strdup_printf("chum_add_instrument_track(%d)",type),LOG_DEBUG);
-meam_add_instrument_track(type);
+//meam_add_instrument_track(type);
 }
 
 void chum_state_of_note(gboolean state, char note){
 cem_add_to_log(g_strdup_printf("chum_state_of_note(%d,%c)",state,note),LOG_DEBUG);
-meam_state_of_note( state,  note);
+//meam_state_of_note( state,  note);
 }
 
 void chum_toggle_note(char note){
 cem_add_to_log(g_strdup_printf("chum_toggle_note(%c)",note),LOG_DEBUG);
-meam_toggle_note(note);
+//meam_toggle_note(note);
 }
 
 void chum_toggle_note_on_octave(char note, int octave){
 cem_add_to_log(g_strdup_printf("chum_toggle_note_on_octave(%c,%d)",note,octave),LOG_DEBUG);
-meam_toggle_note_on_octave(note,octave);
+
+jammo_instrument_track_set_note(instrument_track,note,octave);
+//meam_toggle_note_on_octave(note,octave);
+}
+
+void chum_slider_freq(int a){
+jammo_instrument_track_set_slider_frequency(instrument_track,a);
+}
+
+
+void chum_slider_state(gboolean b){
+jammo_instrument_track_set_slider_state(instrument_track,b);
 }
 
 void chum_print_note_table(){
 cem_add_to_log(g_strdup_printf("chum_print_note_table()"),LOG_DEBUG);
-meam_print_note_table();
+//meam_print_note_table();
 }
 
 
 void chum_octave_up() {
 cem_add_to_log(g_strdup_printf("chum_octave_up()"),LOG_DEBUG);
-meam_octave_up();
+//meam_octave_up();
 }
 
 void chum_octave_down(){
 cem_add_to_log(g_strdup_printf("chum_octave_down()"),LOG_DEBUG);
-meam_octave_down();
+//meam_octave_down();
 }
 
 GList* chum_get_all_songs(){
@@ -447,13 +536,13 @@ return file_helper_get_all_songs();
 
 
 guint chum_get_meter_of_track(int track_number){
-guint meter=meam_get_meter_of_track(track_number);
+guint meter=4; // meam_get_meter_of_track(track_number);
 cem_add_to_log(g_strdup_printf("chum_get_meter_of_track(%d) [%u]",track_number,meter),LOG_DEBUG);
 return meter;
 }
 
 guint chum_get_tempo_of_track(int track_number){
-guint tempo=meam_get_tempo_of_track(track_number);
+guint tempo=130; //meam_get_tempo_of_track(track_number);
 cem_add_to_log(g_strdup_printf("chum_get_tempo_of_track(%d) [%u]",track_number,tempo),LOG_DEBUG);
 return tempo;
 }
