@@ -8,7 +8,8 @@ This file is for clutter based gui and it handles config file reading
 #ifndef _CHUM_H_
 #define _CHUM_H_
 
-#include "../meam/sequencer/sample.h" //We want return Sample*
+#include "../meam/jammo-sample.h" //We want return Sample*
+#include "../meam/jammo-editing-track.h"
 
 /**
  * Defines default folders.
@@ -21,11 +22,17 @@ This file is for clutter based gui and it handles config file reading
 
 #define DATA_DIR "/opt/jammo"
 
-#define THEMES_DIR "/opt/jammo/themes"
-#define SONGS_DIR "/opt/jammo/songs"
+#define THEMES_DIR DATA_DIR "/themes"
+#define SONGS_DIR DATA_DIR "/songs"
 
+extern JammoEditingTrack* editing_track;
+extern JammoEditingTrack* backing_track;
 
-void remove_track (Track *trc); //FIXME. this is not right place for this
+void chum_test_instrument(int type);
+void chum_slider_freq(int a);
+void chum_slider_state(gboolean b);
+
+void remove_track (JammoTrack *trc); //FIXME. this is not right place for this
 
 void chum_report_melodic_contour(float freq);
 
@@ -38,7 +45,7 @@ void chum_go_next();
 void chum_go_screen(int screen_number);
 void chum_change_to_game(int game_number);
 void chum_change_theme(int theme_number);
-void chum_create_new_empty_track();
+JammoEditingTrack* chum_create_new_empty_track();
 
 int chum_get_current_theme();
 const char* chum_get_theme_folder(int index);
@@ -48,15 +55,12 @@ int chum_get_current_song();
 const char* chum_get_song_folder(int index);
 void chum_change_to_song(int song_number);
 
-void chum_play_one_sample(char* filename);
-void chum_stop_one_sample();
-
 
 void chum_stop_sequencer();
 void chum_play_sequencer();
-Sample *chum_add_new_sample_to_track(int track_number, const gchar srcLocation[], guint64 startTime);
-Sample *chum_add_new_sample_to_track_nth_slot(int track_number, const gchar srcLocation[], guint slot);
-void chum_remove_sample_from_slot(guint track_number,int slot);
+JammoSample* chum_add_new_sample_to_track(JammoEditingTrack* track, const gchar* srcLocation, guint64 startTime);
+JammoSample* chum_add_new_sample_to_track_nth_slot(JammoEditingTrack* track, const gchar* srcLocation, guint slot);
+void chum_remove_sample_from_slot(JammoEditingTrack* track,int slot);
 
 void chum_get_all_slot_info(int track_number);
 
