@@ -97,7 +97,7 @@ int i,j;
   GList *l;
   for (l = children; l; l = l->next){
     JammoTexture *actor = l->data;
-    gchar *name = clutter_actor_get_name(CLUTTER_ACTOR(actor)); //This gives warning!
+    const gchar *name = clutter_actor_get_name(CLUTTER_ACTOR(actor));
     printf ("name is %s\n",name);
        gfloat x0_f,y0_f;
        clutter_actor_get_position (CLUTTER_ACTOR(actor),&x0_f,&y0_f);
@@ -172,7 +172,7 @@ put_in_timeline(dropped_actor,icon_place_of_dropped);
   g_object_get(G_OBJECT(dropped_actor), "sound-file", &sound, NULL);
   gchar* buffer0;
   buffer0 = g_strdup_printf("%s/themes/%s/%s",DATA_DIR,chum_get_theme_folder(chum_get_current_theme()), sound);
-  chum_add_new_sample_to_track_nth_slot(0,buffer0,slot_number);
+  chum_add_new_sample_to_track_nth_slot(editing_track,buffer0,slot_number);
 #ifdef ALL_BEHAVING_ARE_DISABLED_TEMPORARILY
 //stop behaving
   GList *behaviours_and_actors = get_current_behaviours_and_actors();
@@ -278,12 +278,21 @@ static void object_released (JammoTexture *actor, ClutterEvent *event, gpointer
        y_release<=y_start_of_dragging+CLICKING_THRESHOLD &&
        y_release>=y_start_of_dragging-CLICKING_THRESHOLD   )
      {
-       gchar *sound;
-       g_object_get(G_OBJECT(actor), "sound-file", &sound, NULL);
-       gchar* buffer0;
-       buffer0 = g_strdup_printf("%s/themes/%s/%s",DATA_DIR,chum_get_theme_folder(chum_get_current_theme()), sound);
+     	JammoSample* sample;
+	
+/*	if ((sample = jammo_texture_get_sample(JAMMO_TEXTURE(actor)))) {
+There is no path of sound-file in JSON. So...
+*/
+  gchar* buffer0;
+  buffer0 = g_strdup_printf("%s/themes/%s/%s",DATA_DIR,chum_get_theme_folder(chum_get_current_theme()), jammo_texture_get_sound_file_name(JAMMO_TEXTURE(actor)));
+  sample = jammo_sample_new_from_file(buffer0);
+		jammo_sample_stop_all();
+		jammo_sample_play(sample);
+/*	}
+*/
+  g_free(buffer0);
+  g_object_unref(sample);
 
-       chum_play_one_sample(buffer0);
        //if icon is  moved little bit, we should move it back (other these little moves can be cumulated*/
        clutter_actor_set_position (CLUTTER_ACTOR(actor), x_start_of_dragging + x_drag_offset, y_start_of_dragging + y_drag_offset );
 
