@@ -91,12 +91,12 @@ if (is_this_initialized(stage))
 printf("not yet initialized\n");
 
 asked=stage;
-printf("going to loop\n");
-while ( (asked !=-1) & (!(is_this_initialized(stage))) ) 
+printf("preloader: going to loop\n");
+while ( (asked !=-1) & (!(is_this_initialized(stage))) )
 {
  // & (!(is_this_initialized(stage))))
-  
-    printf("in while loop\n");
+
+    printf("preloader: in while loop\n");
   g_usleep( 0.2 * G_USEC_PER_SEC );
   /*
    if (is_this_initialized(stage)) //backdoor
@@ -106,7 +106,7 @@ while ( (asked !=-1) & (!(is_this_initialized(stage))) )
     }
     */
   }
-printf("loop ready\n");
+printf("preloader: loop ready\n");
 }
 
 
